<?php
date_default_timezone_set('Asia/Shanghai');
header('Content-Type: application/json');

// ====== 数据库配置 ======
$db_host = "localhost";
$db_user = "jz_cuaye_cn";    
$db_pass = "QJdA6jyjTrMheSdi";
$db_name = "jz_cuaye_cn";

try {
    // 验证输入数据
    if (!isset($_POST['id']) || !is_numeric($_POST['id'])) {
        throw new Exception("无效的记录ID");
    }
    $id = (int)$_POST['id'];
    if ($id <= 0) throw new Exception("非法ID");

    // 处理日期时间格式（新增补秒逻辑）
    $datetime = $_POST['datetime'] ?? '';
    $datetime = date('Y-m-d H:i:s', strtotime($datetime)); // 强制补足秒数

    $name = htmlspecialchars($_POST['name'] ?? '');
    $amount = (float)($_POST['amount'] ?? 0);

    // 加强金额验证（必须大于0）
    if (empty($datetime) || empty($name) || $amount <= 0) {
        throw new Exception("提交数据不完整");
    }

    // 创建数据库连接
    $conn = new mysqli($db_host, $db_user, $db_pass, $db_name);
    if ($conn->connect_error) {
        throw new Exception("数据库连接失败: " . $conn->connect_error);
    }

    // 开启事务
    $conn->begin_transaction();

    try {
        // 获取原记录时间
        $stmt = $conn->prepare("SELECT datetime FROM bills WHERE id = ?");
        $stmt->bind_param("i", $id);
        if (!$stmt->execute()) {
            throw new Exception("查询失败: " . $stmt->error);
        }
        $result = $stmt->get_result();
        if ($result->num_rows === 0) {
            throw new Exception("记录不存在");
        }
        $oldDate = new DateTime($result->fetch_assoc()['datetime']);

        // 更新数据库记录
        $stmt = $conn->prepare("UPDATE bills SET name=?, amount=?, datetime=? WHERE id=?");
        $stmt->bind_param("sdsi", $name, $amount, $datetime, $id);
        if (!$stmt->execute()) {
            throw new Exception("更新失败: " . $stmt->error);
        }

        // 处理文件记录
        $newDate = new DateTime($datetime);
        
        // 原文件路径（修正月份为两位数格式）
        $oldFilePath = sprintf(
            "%s/zandan/%s/%syue/%s.txt",
            $_SERVER['DOCUMENT_ROOT'],
            $oldDate->format('Y'),
            $oldDate->format('m'), // 原为'n'，改为'm'获取两位数月份
            $oldDate->format('d') // 确保日期也是两位数
        );

        // 新文件路径（同上修正）
        $newFilePath = sprintf(
            "%s/zandan/%s/%syue/%s.txt",
            $_SERVER['DOCUMENT_ROOT'],
            $newDate->format('Y'),
            $newDate->format('m'),
            $newDate->format('d')
        );

        // 处理原文件（新增错误日志）
        if (file_exists($oldFilePath)) {
            $content = file_get_contents($oldFilePath);
            $pattern = "/#ID:$id\n用途：(.*?)\n金额：￥(.*?)\n时间：(.*?)\n\n/s";
            $newContent = preg_replace($pattern, '', $content, -1, $count);
            
            if ($count === 0) {
                error_log("[UPDATE] 原文件记录未找到：ID=$id, 路径=$oldFilePath");
                throw new Exception("原文件记录未找到");
            }
            
            if (!file_put_contents($oldFilePath, $newContent)) {
                error_log("[UPDATE] 原文件写入失败：路径=$oldFilePath");
                throw new Exception("原文件更新失败");
            }
        } else {
            error_log("[UPDATE] 原文件不存在：路径=$oldFilePath");
        }

        // 创建新目录（确保权限）
        if (!is_dir(dirname($newFilePath))) {
            if (!mkdir(dirname($newFilePath), 0755, true)) {
                error_log("[UPDATE] 目录创建失败：路径=" . dirname($newFilePath));
                throw new Exception("目录创建失败");
            }
        }

        // 追加新记录（严格格式化金额）
        $fileContent = sprintf(
            "#ID:%d\n用途：%s\n金额：￥%.2f\n时间：%s\n\n",
            $id,
            $name,
            number_format($amount, 2),
            $newDate->format('Y年m月d日 H时i分s秒')
        );
        
        if (!file_put_contents($newFilePath, $fileContent, FILE_APPEND)) {
            error_log("[UPDATE] 新文件写入失败：路径=$newFilePath");
            throw new Exception("新文件写入失败");
        }

        $conn->commit();
        
        echo json_encode([
            'status' => 'success',
            'message' => '更新成功'
        ]);

    } catch (Exception $e) {
        $conn->rollback();
        throw $e;
    }

} catch (Exception $e) {
    http_response_code(400);
    echo json_encode([
        'status' => 'error',
        'message' => $e->getMessage(),
        'error_code' => $e->getCode()
    ]);
} finally {
    if (isset($conn)) $conn->close();
}